/****************************************************************************
** Meta object code from reading C++ file 'VolumeMeter.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../obs-studio/frontend/components/VolumeMeter.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'VolumeMeter.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11VolumeMeterE_t {};
} // unnamed namespace

template <> constexpr inline auto VolumeMeter::qt_create_metaobjectdata<qt_meta_tag_ZN11VolumeMeterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VolumeMeter",
        "onSourceDestroyed",
        "",
        "backgroundNominalColor",
        "QColor",
        "backgroundWarningColor",
        "backgroundErrorColor",
        "foregroundNominalColor",
        "foregroundWarningColor",
        "foregroundErrorColor",
        "backgroundNominalColorDisabled",
        "backgroundWarningColorDisabled",
        "backgroundErrorColorDisabled",
        "foregroundNominalColorDisabled",
        "foregroundWarningColorDisabled",
        "foregroundErrorColorDisabled",
        "magnitudeColor",
        "majorTickColor",
        "minorTickColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onSourceDestroyed'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'backgroundNominalColor'
        QtMocHelpers::PropertyData<QColor>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backgroundWarningColor'
        QtMocHelpers::PropertyData<QColor>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backgroundErrorColor'
        QtMocHelpers::PropertyData<QColor>(6, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'foregroundNominalColor'
        QtMocHelpers::PropertyData<QColor>(7, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'foregroundWarningColor'
        QtMocHelpers::PropertyData<QColor>(8, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'foregroundErrorColor'
        QtMocHelpers::PropertyData<QColor>(9, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backgroundNominalColorDisabled'
        QtMocHelpers::PropertyData<QColor>(10, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backgroundWarningColorDisabled'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backgroundErrorColorDisabled'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'foregroundNominalColorDisabled'
        QtMocHelpers::PropertyData<QColor>(13, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'foregroundWarningColorDisabled'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'foregroundErrorColorDisabled'
        QtMocHelpers::PropertyData<QColor>(15, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'magnitudeColor'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'majorTickColor'
        QtMocHelpers::PropertyData<QColor>(17, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'minorTickColor'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VolumeMeter, qt_meta_tag_ZN11VolumeMeterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VolumeMeter::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VolumeMeterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VolumeMeterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11VolumeMeterE_t>.metaTypes,
    nullptr
} };

void VolumeMeter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VolumeMeter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onSourceDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->getBackgroundNominalColor(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->getBackgroundWarningColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->getBackgroundErrorColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->getForegroundNominalColor(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->getForegroundWarningColor(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->getForegroundErrorColor(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->getBackgroundNominalColorDisabled(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->getBackgroundWarningColorDisabled(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->getBackgroundErrorColorDisabled(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->getForegroundNominalColorDisabled(); break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->getForegroundWarningColorDisabled(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->getForegroundErrorColorDisabled(); break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->getMagnitudeColor(); break;
        case 13: *reinterpret_cast<QColor*>(_v) = _t->getMajorTickColor(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->getMinorTickColor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackgroundNominalColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setBackgroundWarningColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setBackgroundErrorColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setForegroundNominalColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setForegroundWarningColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setForegroundErrorColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setBackgroundNominalColorDisabled(*reinterpret_cast<QColor*>(_v)); break;
        case 7: _t->setBackgroundWarningColorDisabled(*reinterpret_cast<QColor*>(_v)); break;
        case 8: _t->setBackgroundErrorColorDisabled(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setForegroundNominalColorDisabled(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setForegroundWarningColorDisabled(*reinterpret_cast<QColor*>(_v)); break;
        case 11: _t->setForegroundErrorColorDisabled(*reinterpret_cast<QColor*>(_v)); break;
        case 12: _t->setMagnitudeColor(*reinterpret_cast<QColor*>(_v)); break;
        case 13: _t->setMajorTickColor(*reinterpret_cast<QColor*>(_v)); break;
        case 14: _t->setMinorTickColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *VolumeMeter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VolumeMeter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VolumeMeterE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int VolumeMeter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
