/********************************************************************************
** Form generated from reading UI file 'OBSBasicTransform.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBSBASICTRANSFORM_H
#define UI_OBSBASICTRANSFORM_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_OBSBasicTransform
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *outerFrame;
    QVBoxLayout *verticalLayout_3;
    QFrame *transformSettings;
    QGridLayout *gridLayout_2;
    QLabel *sizeWidthLabel;
    QLabel *positionXLabel;
    QDoubleSpinBox *sizeX;
    QLabel *label_2;
    QDoubleSpinBox *positionX;
    QDoubleSpinBox *rotation;
    QLabel *label_3;
    QLabel *label;
    QSpacerItem *horizontalSpacer_3;
    QLabel *positionYLabel;
    QDoubleSpinBox *positionY;
    QDoubleSpinBox *sizeY;
    QLabel *sizeHeightLabel;
    QFrame *alignmentWidget;
    QVBoxLayout *alignmentLayout;
    QLabel *label_4;
    QFrame *boundsSettings;
    QGridLayout *gridLayout_3;
    QComboBox *boundsType;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_7;
    QFrame *alignmentWidget2;
    QVBoxLayout *boundsAlignmentLayout;
    QLabel *label_6;
    QLabel *boundsWidthLabel;
    QLabel *boundsHeightLabel;
    QDoubleSpinBox *boundsWidth;
    QDoubleSpinBox *boundsHeight;
    QCheckBox *cropToBounds;
    QFrame *cropSettings;
    QGridLayout *gridLayout;
    QLabel *cropLeftLabel;
    QLabel *cropRightLabel;
    QSpinBox *cropBottom;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *cropRight;
    QSpinBox *cropLeft;
    QLabel *cropTopLabel;
    QSpinBox *cropTop;
    QLabel *label_8;
    QLabel *cropBottomLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OBSBasicTransform)
    {
        if (OBSBasicTransform->objectName().isEmpty())
            OBSBasicTransform->setObjectName("OBSBasicTransform");
        OBSBasicTransform->resize(900, 280);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OBSBasicTransform->sizePolicy().hasHeightForWidth());
        OBSBasicTransform->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(OBSBasicTransform);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        outerFrame = new QFrame(OBSBasicTransform);
        outerFrame->setObjectName("outerFrame");
        outerFrame->setFrameShape(QFrame::NoFrame);
        outerFrame->setFrameShadow(QFrame::Plain);
        outerFrame->setLineWidth(0);
        verticalLayout_3 = new QVBoxLayout(outerFrame);
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        transformSettings = new QFrame(outerFrame);
        transformSettings->setObjectName("transformSettings");
        transformSettings->setFrameShape(QFrame::NoFrame);
        transformSettings->setFrameShadow(QFrame::Plain);
        transformSettings->setLineWidth(0);
        gridLayout_2 = new QGridLayout(transformSettings);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setHorizontalSpacing(8);
        gridLayout_2->setVerticalSpacing(2);
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        sizeWidthLabel = new QLabel(transformSettings);
        sizeWidthLabel->setObjectName("sizeWidthLabel");
        sizeWidthLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(sizeWidthLabel, 1, 2, 1, 1);

        positionXLabel = new QLabel(transformSettings);
        positionXLabel->setObjectName("positionXLabel");
        positionXLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(positionXLabel, 1, 0, 1, 1);

        sizeX = new QDoubleSpinBox(transformSettings);
        sizeX->setObjectName("sizeX");
        sizeX->setMinimumSize(QSize(120, 0));
        sizeX->setMaximumSize(QSize(120, 16777215));
        sizeX->setDecimals(2);
        sizeX->setMinimum(-90001.000000000000000);
        sizeX->setMaximum(90001.000000000000000);
        sizeX->setSingleStep(1.000000000000000);

        gridLayout_2->addWidget(sizeX, 1, 3, 1, 1);

        label_2 = new QLabel(transformSettings);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 0, 4, 1, 1);

        positionX = new QDoubleSpinBox(transformSettings);
        positionX->setObjectName("positionX");
        positionX->setMinimumSize(QSize(120, 0));
        positionX->setMaximumSize(QSize(120, 16777215));
        positionX->setDecimals(2);
        positionX->setMinimum(-90001.000000000000000);
        positionX->setMaximum(90001.000000000000000);

        gridLayout_2->addWidget(positionX, 1, 1, 1, 1);

        rotation = new QDoubleSpinBox(transformSettings);
        rotation->setObjectName("rotation");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(rotation->sizePolicy().hasHeightForWidth());
        rotation->setSizePolicy(sizePolicy1);
        rotation->setMinimumSize(QSize(120, 0));
        rotation->setMaximumSize(QSize(120, 16777215));
        rotation->setMinimum(-360.000000000000000);
        rotation->setMaximum(360.000000000000000);
        rotation->setSingleStep(0.100000000000000);

        gridLayout_2->addWidget(rotation, 1, 4, 1, 1);

        label_3 = new QLabel(transformSettings);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_3, 0, 2, 1, 2);

        label = new QLabel(transformSettings);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_2->addWidget(label, 0, 0, 1, 2);

        horizontalSpacer_3 = new QSpacerItem(0, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 1, 6, 1, 1);

        positionYLabel = new QLabel(transformSettings);
        positionYLabel->setObjectName("positionYLabel");
        positionYLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(positionYLabel, 2, 0, 1, 1);

        positionY = new QDoubleSpinBox(transformSettings);
        positionY->setObjectName("positionY");
        positionY->setMinimumSize(QSize(120, 0));
        positionY->setMaximumSize(QSize(120, 16777215));
        positionY->setDecimals(2);
        positionY->setMinimum(-90001.000000000000000);
        positionY->setMaximum(90001.000000000000000);

        gridLayout_2->addWidget(positionY, 2, 1, 1, 1);

        sizeY = new QDoubleSpinBox(transformSettings);
        sizeY->setObjectName("sizeY");
        sizeY->setMinimumSize(QSize(120, 0));
        sizeY->setMaximumSize(QSize(120, 16777215));
        sizeY->setDecimals(2);
        sizeY->setMinimum(-90001.000000000000000);
        sizeY->setMaximum(90001.000000000000000);
        sizeY->setSingleStep(1.000000000000000);

        gridLayout_2->addWidget(sizeY, 2, 3, 1, 1);

        sizeHeightLabel = new QLabel(transformSettings);
        sizeHeightLabel->setObjectName("sizeHeightLabel");
        sizeHeightLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(sizeHeightLabel, 2, 2, 1, 1);

        alignmentWidget = new QFrame(transformSettings);
        alignmentWidget->setObjectName("alignmentWidget");
        alignmentWidget->setFrameShape(QFrame::NoFrame);
        alignmentWidget->setFrameShadow(QFrame::Plain);
        alignmentWidget->setLineWidth(0);
        alignmentLayout = new QVBoxLayout(alignmentWidget);
        alignmentLayout->setSpacing(0);
        alignmentLayout->setObjectName("alignmentLayout");
        alignmentLayout->setContentsMargins(0, 0, 0, 0);

        gridLayout_2->addWidget(alignmentWidget, 1, 5, 1, 1);

        label_4 = new QLabel(transformSettings);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 0, 5, 1, 1);


        verticalLayout_3->addWidget(transformSettings);

        boundsSettings = new QFrame(outerFrame);
        boundsSettings->setObjectName("boundsSettings");
        boundsSettings->setFrameShape(QFrame::NoFrame);
        boundsSettings->setFrameShadow(QFrame::Plain);
        boundsSettings->setLineWidth(0);
        gridLayout_3 = new QGridLayout(boundsSettings);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setHorizontalSpacing(8);
        gridLayout_3->setVerticalSpacing(2);
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        boundsType = new QComboBox(boundsSettings);
        boundsType->addItem(QString());
        boundsType->addItem(QString());
        boundsType->addItem(QString());
        boundsType->addItem(QString());
        boundsType->addItem(QString());
        boundsType->addItem(QString());
        boundsType->addItem(QString());
        boundsType->setObjectName("boundsType");

        gridLayout_3->addWidget(boundsType, 1, 0, 1, 3);

        horizontalSpacer_4 = new QSpacerItem(0, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 0, 7, 4, 1);

        label_7 = new QLabel(boundsSettings);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 0, 0, 1, 3);

        alignmentWidget2 = new QFrame(boundsSettings);
        alignmentWidget2->setObjectName("alignmentWidget2");
        alignmentWidget2->setFrameShape(QFrame::NoFrame);
        alignmentWidget2->setFrameShadow(QFrame::Plain);
        alignmentWidget2->setLineWidth(0);
        boundsAlignmentLayout = new QVBoxLayout(alignmentWidget2);
        boundsAlignmentLayout->setObjectName("boundsAlignmentLayout");
        boundsAlignmentLayout->setContentsMargins(0, 0, 0, 0);

        gridLayout_3->addWidget(alignmentWidget2, 1, 3, 1, 1);

        label_6 = new QLabel(boundsSettings);
        label_6->setObjectName("label_6");

        gridLayout_3->addWidget(label_6, 0, 3, 1, 1);

        boundsWidthLabel = new QLabel(boundsSettings);
        boundsWidthLabel->setObjectName("boundsWidthLabel");
        boundsWidthLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(boundsWidthLabel, 2, 0, 1, 1);

        boundsHeightLabel = new QLabel(boundsSettings);
        boundsHeightLabel->setObjectName("boundsHeightLabel");
        boundsHeightLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(boundsHeightLabel, 3, 0, 1, 1);

        boundsWidth = new QDoubleSpinBox(boundsSettings);
        boundsWidth->setObjectName("boundsWidth");
        boundsWidth->setEnabled(false);
        boundsWidth->setMinimumSize(QSize(120, 0));
        boundsWidth->setMaximumSize(QSize(120, 16777215));
        boundsWidth->setDecimals(2);
        boundsWidth->setMinimum(1.000000000000000);
        boundsWidth->setMaximum(90001.000000000000000);

        gridLayout_3->addWidget(boundsWidth, 2, 1, 1, 1);

        boundsHeight = new QDoubleSpinBox(boundsSettings);
        boundsHeight->setObjectName("boundsHeight");
        boundsHeight->setEnabled(false);
        boundsHeight->setMinimumSize(QSize(120, 0));
        boundsHeight->setMaximumSize(QSize(120, 16777215));
        boundsHeight->setDecimals(2);
        boundsHeight->setMinimum(1.000000000000000);
        boundsHeight->setMaximum(90001.000000000000000);

        gridLayout_3->addWidget(boundsHeight, 3, 1, 1, 1);

        cropToBounds = new QCheckBox(boundsSettings);
        cropToBounds->setObjectName("cropToBounds");
        cropToBounds->setEnabled(false);
        cropToBounds->setMaximumSize(QSize(100, 16777215));

        gridLayout_3->addWidget(cropToBounds, 2, 2, 1, 1);


        verticalLayout_3->addWidget(boundsSettings);

        cropSettings = new QFrame(outerFrame);
        cropSettings->setObjectName("cropSettings");
        cropSettings->setLineWidth(0);
        gridLayout = new QGridLayout(cropSettings);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(8);
        gridLayout->setVerticalSpacing(2);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        cropLeftLabel = new QLabel(cropSettings);
        cropLeftLabel->setObjectName("cropLeftLabel");
        cropLeftLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(cropLeftLabel, 1, 0, 1, 1);

        cropRightLabel = new QLabel(cropSettings);
        cropRightLabel->setObjectName("cropRightLabel");
        cropRightLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(cropRightLabel, 1, 2, 1, 1);

        cropBottom = new QSpinBox(cropSettings);
        cropBottom->setObjectName("cropBottom");
        sizePolicy1.setHeightForWidth(cropBottom->sizePolicy().hasHeightForWidth());
        cropBottom->setSizePolicy(sizePolicy1);
        cropBottom->setMinimumSize(QSize(120, 0));
        cropBottom->setMaximumSize(QSize(120, 16777215));
        cropBottom->setMaximum(100000);

        gridLayout->addWidget(cropBottom, 2, 3, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 4, 1, 1);

        cropRight = new QSpinBox(cropSettings);
        cropRight->setObjectName("cropRight");
        sizePolicy1.setHeightForWidth(cropRight->sizePolicy().hasHeightForWidth());
        cropRight->setSizePolicy(sizePolicy1);
        cropRight->setMinimumSize(QSize(120, 0));
        cropRight->setMaximumSize(QSize(120, 16777215));
        cropRight->setMaximum(100000);

        gridLayout->addWidget(cropRight, 1, 3, 1, 1);

        cropLeft = new QSpinBox(cropSettings);
        cropLeft->setObjectName("cropLeft");
        sizePolicy1.setHeightForWidth(cropLeft->sizePolicy().hasHeightForWidth());
        cropLeft->setSizePolicy(sizePolicy1);
        cropLeft->setMinimumSize(QSize(120, 0));
        cropLeft->setMaximumSize(QSize(120, 16777215));
        cropLeft->setMaximum(100000);

        gridLayout->addWidget(cropLeft, 1, 1, 1, 1);

        cropTopLabel = new QLabel(cropSettings);
        cropTopLabel->setObjectName("cropTopLabel");
        cropTopLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(cropTopLabel, 2, 0, 1, 1);

        cropTop = new QSpinBox(cropSettings);
        cropTop->setObjectName("cropTop");
        sizePolicy1.setHeightForWidth(cropTop->sizePolicy().hasHeightForWidth());
        cropTop->setSizePolicy(sizePolicy1);
        cropTop->setMinimumSize(QSize(120, 0));
        cropTop->setMaximumSize(QSize(120, 16777215));
        cropTop->setMaximum(100000);

        gridLayout->addWidget(cropTop, 2, 1, 1, 1);

        label_8 = new QLabel(cropSettings);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 0, 0, 1, 1);

        cropBottomLabel = new QLabel(cropSettings);
        cropBottomLabel->setObjectName("cropBottomLabel");
        cropBottomLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(cropBottomLabel, 2, 2, 1, 1);


        verticalLayout_3->addWidget(cropSettings);

        buttonBox = new QDialogButtonBox(outerFrame);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout_3->addWidget(buttonBox);


        verticalLayout->addWidget(outerFrame);

        QWidget::setTabOrder(positionX, positionY);
        QWidget::setTabOrder(positionY, sizeX);
        QWidget::setTabOrder(sizeX, sizeY);
        QWidget::setTabOrder(sizeY, rotation);
        QWidget::setTabOrder(rotation, boundsType);
        QWidget::setTabOrder(boundsType, boundsWidth);
        QWidget::setTabOrder(boundsWidth, boundsHeight);
        QWidget::setTabOrder(boundsHeight, cropToBounds);
        QWidget::setTabOrder(cropToBounds, cropLeft);
        QWidget::setTabOrder(cropLeft, cropRight);
        QWidget::setTabOrder(cropRight, cropTop);
        QWidget::setTabOrder(cropTop, cropBottom);

        retranslateUi(OBSBasicTransform);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, OBSBasicTransform, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(OBSBasicTransform);
    } // setupUi

    void retranslateUi(QDialog *OBSBasicTransform)
    {
        OBSBasicTransform->setWindowTitle(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow", nullptr));
        outerFrame->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "dialog-container", nullptr)));
        transformSettings->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "dialog-container dialog-frame", nullptr)));
#if QT_CONFIG(accessibility)
        sizeWidthLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Width", nullptr));
#endif // QT_CONFIG(accessibility)
        sizeWidthLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Width", nullptr));
#if QT_CONFIG(accessibility)
        positionXLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Accessible.PositionX", nullptr));
#endif // QT_CONFIG(accessibility)
        positionXLabel->setText(QCoreApplication::translate("OBSBasicTransform", "X", nullptr));
#if QT_CONFIG(accessibility)
        sizeX->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Width", nullptr));
#endif // QT_CONFIG(accessibility)
        sizeX->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        label_2->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Rotation", nullptr));
#endif // QT_CONFIG(accessibility)
        label_2->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Rotation", nullptr));
        label_2->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
#if QT_CONFIG(accessibility)
        positionX->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.PositionX", nullptr));
#endif // QT_CONFIG(accessibility)
        positionX->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        rotation->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Rotation", nullptr));
#endif // QT_CONFIG(accessibility)
        rotation->setSuffix(QCoreApplication::translate("OBSBasicTransform", "\302\260", nullptr));
#if QT_CONFIG(accessibility)
        label_3->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Size", nullptr));
#endif // QT_CONFIG(accessibility)
        label_3->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Size", nullptr));
        label_3->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
#if QT_CONFIG(accessibility)
        label->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Position", nullptr));
#endif // QT_CONFIG(accessibility)
        label->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Position", nullptr));
        label->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
#if QT_CONFIG(accessibility)
        positionYLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Accessible.PositionY", nullptr));
#endif // QT_CONFIG(accessibility)
        positionYLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Y", nullptr));
#if QT_CONFIG(accessibility)
        positionY->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.PositionY", nullptr));
#endif // QT_CONFIG(accessibility)
        positionY->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        sizeY->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Height", nullptr));
#endif // QT_CONFIG(accessibility)
        sizeY->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        sizeHeightLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Height", nullptr));
#endif // QT_CONFIG(accessibility)
        sizeHeightLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Height", nullptr));
#if QT_CONFIG(accessibility)
        label_4->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Alignment", nullptr));
#endif // QT_CONFIG(accessibility)
        label_4->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Alignment", nullptr));
        label_4->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
        boundsSettings->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "dialog-container dialog-frame", nullptr)));
        boundsType->setItemText(0, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.None", nullptr));
        boundsType->setItemText(1, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.Stretch", nullptr));
        boundsType->setItemText(2, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.ScaleInner", nullptr));
        boundsType->setItemText(3, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.ScaleOuter", nullptr));
        boundsType->setItemText(4, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.ScaleToWidth", nullptr));
        boundsType->setItemText(5, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.ScaleToHeight", nullptr));
        boundsType->setItemText(6, QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType.MaxOnly", nullptr));

#if QT_CONFIG(accessibility)
        boundsType->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsType", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        label_7->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Bounds", nullptr));
#endif // QT_CONFIG(accessibility)
        label_7->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Bounds", nullptr));
        label_7->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
#if QT_CONFIG(accessibility)
        label_6->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Alignment", nullptr));
#endif // QT_CONFIG(accessibility)
        label_6->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Alignment", nullptr));
        label_6->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
#if QT_CONFIG(accessibility)
        boundsWidthLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsWidth", nullptr));
#endif // QT_CONFIG(accessibility)
        boundsWidthLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Width", nullptr));
#if QT_CONFIG(accessibility)
        boundsHeightLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsHeight", nullptr));
#endif // QT_CONFIG(accessibility)
        boundsHeightLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Height", nullptr));
#if QT_CONFIG(accessibility)
        boundsWidth->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsWidth", nullptr));
#endif // QT_CONFIG(accessibility)
        boundsWidth->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        boundsHeight->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsHeight", nullptr));
#endif // QT_CONFIG(accessibility)
        boundsHeight->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        cropToBounds->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.BoundsAlignment", nullptr));
#endif // QT_CONFIG(accessibility)
        cropToBounds->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.CropToBounds", nullptr));
        cropToBounds->setProperty("class", QVariant(QString()));
        cropSettings->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "dialog-container dialog-frame", nullptr)));
#if QT_CONFIG(accessibility)
        cropLeftLabel->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.CropLeft", nullptr));
#endif // QT_CONFIG(accessibility)
        cropLeftLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Left", nullptr));
        cropRightLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Right", nullptr));
#if QT_CONFIG(accessibility)
        cropBottom->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.CropBottom", nullptr));
#endif // QT_CONFIG(accessibility)
        cropBottom->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        cropRight->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.CropRight", nullptr));
#endif // QT_CONFIG(accessibility)
        cropRight->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        cropLeft->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.CropLeft", nullptr));
#endif // QT_CONFIG(accessibility)
        cropLeft->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
        cropTopLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Top", nullptr));
#if QT_CONFIG(accessibility)
        cropTop->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.CropTop", nullptr));
#endif // QT_CONFIG(accessibility)
        cropTop->setSuffix(QCoreApplication::translate("OBSBasicTransform", " px", nullptr));
#if QT_CONFIG(accessibility)
        label_8->setAccessibleName(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Crop", nullptr));
#endif // QT_CONFIG(accessibility)
        label_8->setText(QCoreApplication::translate("OBSBasicTransform", "Basic.TransformWindow.Crop", nullptr));
        label_8->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicTransform", "subtitle", nullptr)));
        cropBottomLabel->setText(QCoreApplication::translate("OBSBasicTransform", "Bottom", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OBSBasicTransform: public Ui_OBSBasicTransform {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OBSBASICTRANSFORM_H
