/********************************************************************************
** Form generated from reading UI file 'OBSBasicSourceSelect.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBSBASICSOURCESELECT_H
#define UI_OBSBASICSOURCESELECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "components/FlowFrame.hpp"

QT_BEGIN_NAMESPACE

class Ui_OBSBasicSourceSelect
{
public:
    QVBoxLayout *verticalLayout_7;
    QFrame *dialogInner;
    QHBoxLayout *horizontalLayout;
    QFrame *selectTypeFrame;
    QVBoxLayout *verticalLayout;
    QListWidget *sourceTypeList;
    QSpacerItem *verticalSpacer_2;
    QFrame *sourcesFrame;
    QVBoxLayout *verticalLayout_8;
    QFrame *selectSourceContainer;
    QVBoxLayout *verticalLayout_2;
    QLabel *sourceSelectTitle;
    QLabel *sourceSelectDescription;
    QFrame *deprecatedFrame;
    QVBoxLayout *verticalLayout_3;
    QLabel *deprecatedCreateLabel;
    QFrame *selectSourceFrame;
    QVBoxLayout *verticalLayout_6;
    QPushButton *createNewSource;
    QLabel *noExistingLabel;
    QScrollArea *existingScrollArea;
    QWidget *existingScrollContents;
    QVBoxLayout *verticalLayout_4;
    FlowFrame *existingListFrame;
    QSpacerItem *verticalSpacer;
    QWidget *addExistingContainer;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *addExistingButton;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *horizontalSpacer_3;
    QFrame *footer;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *sourceVisible;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OBSBasicSourceSelect)
    {
        if (OBSBasicSourceSelect->objectName().isEmpty())
            OBSBasicSourceSelect->setObjectName("OBSBasicSourceSelect");
        OBSBasicSourceSelect->setWindowModality(Qt::NonModal);
        OBSBasicSourceSelect->resize(1040, 620);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OBSBasicSourceSelect->sizePolicy().hasHeightForWidth());
        OBSBasicSourceSelect->setSizePolicy(sizePolicy);
        OBSBasicSourceSelect->setMaximumSize(QSize(16777215, 1000));
        verticalLayout_7 = new QVBoxLayout(OBSBasicSourceSelect);
        verticalLayout_7->setSpacing(0);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        dialogInner = new QFrame(OBSBasicSourceSelect);
        dialogInner->setObjectName("dialogInner");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(dialogInner->sizePolicy().hasHeightForWidth());
        dialogInner->setSizePolicy(sizePolicy1);
        dialogInner->setFrameShape(QFrame::NoFrame);
        dialogInner->setFrameShadow(QFrame::Plain);
        dialogInner->setLineWidth(0);
        horizontalLayout = new QHBoxLayout(dialogInner);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        selectTypeFrame = new QFrame(dialogInner);
        selectTypeFrame->setObjectName("selectTypeFrame");
        selectTypeFrame->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(selectTypeFrame->sizePolicy().hasHeightForWidth());
        selectTypeFrame->setSizePolicy(sizePolicy2);
        selectTypeFrame->setFrameShape(QFrame::NoFrame);
        selectTypeFrame->setFrameShadow(QFrame::Plain);
        selectTypeFrame->setLineWidth(0);
        verticalLayout = new QVBoxLayout(selectTypeFrame);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        sourceTypeList = new QListWidget(selectTypeFrame);
        sourceTypeList->setObjectName("sourceTypeList");
        sizePolicy2.setHeightForWidth(sourceTypeList->sizePolicy().hasHeightForWidth());
        sourceTypeList->setSizePolicy(sizePolicy2);
        sourceTypeList->setMinimumSize(QSize(0, 460));
        sourceTypeList->setFrameShape(QFrame::NoFrame);
        sourceTypeList->setFrameShadow(QFrame::Plain);
        sourceTypeList->setLineWidth(0);
        sourceTypeList->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
        sourceTypeList->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        sourceTypeList->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContentsOnFirstShow);
        sourceTypeList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        sourceTypeList->setProperty("showDropIndicator", QVariant(false));
        sourceTypeList->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
        sourceTypeList->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
        sourceTypeList->setResizeMode(QListView::Adjust);

        verticalLayout->addWidget(sourceTypeList);

        verticalSpacer_2 = new QSpacerItem(17, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        verticalLayout->addItem(verticalSpacer_2);


        horizontalLayout->addWidget(selectTypeFrame);

        sourcesFrame = new QFrame(dialogInner);
        sourcesFrame->setObjectName("sourcesFrame");
        sourcesFrame->setFrameShape(QFrame::NoFrame);
        sourcesFrame->setFrameShadow(QFrame::Plain);
        sourcesFrame->setLineWidth(0);
        verticalLayout_8 = new QVBoxLayout(sourcesFrame);
        verticalLayout_8->setSpacing(0);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        selectSourceContainer = new QFrame(sourcesFrame);
        selectSourceContainer->setObjectName("selectSourceContainer");
        selectSourceContainer->setFrameShape(QFrame::NoFrame);
        selectSourceContainer->setFrameShadow(QFrame::Plain);
        selectSourceContainer->setLineWidth(0);
        verticalLayout_2 = new QVBoxLayout(selectSourceContainer);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        sourceSelectTitle = new QLabel(selectSourceContainer);
        sourceSelectTitle->setObjectName("sourceSelectTitle");

        verticalLayout_2->addWidget(sourceSelectTitle);

        sourceSelectDescription = new QLabel(selectSourceContainer);
        sourceSelectDescription->setObjectName("sourceSelectDescription");

        verticalLayout_2->addWidget(sourceSelectDescription);

        deprecatedFrame = new QFrame(selectSourceContainer);
        deprecatedFrame->setObjectName("deprecatedFrame");
        deprecatedFrame->setFrameShape(QFrame::NoFrame);
        deprecatedFrame->setFrameShadow(QFrame::Plain);
        deprecatedFrame->setLineWidth(0);
        verticalLayout_3 = new QVBoxLayout(deprecatedFrame);
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        deprecatedCreateLabel = new QLabel(deprecatedFrame);
        deprecatedCreateLabel->setObjectName("deprecatedCreateLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Maximum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(deprecatedCreateLabel->sizePolicy().hasHeightForWidth());
        deprecatedCreateLabel->setSizePolicy(sizePolicy3);
        deprecatedCreateLabel->setFrameShape(QFrame::NoFrame);
        deprecatedCreateLabel->setFrameShadow(QFrame::Plain);
        deprecatedCreateLabel->setLineWidth(0);
        deprecatedCreateLabel->setAlignment(Qt::AlignCenter);

        verticalLayout_3->addWidget(deprecatedCreateLabel);


        verticalLayout_2->addWidget(deprecatedFrame);

        selectSourceFrame = new QFrame(selectSourceContainer);
        selectSourceFrame->setObjectName("selectSourceFrame");
        selectSourceFrame->setFrameShadow(QFrame::Plain);
        selectSourceFrame->setLineWidth(0);
        verticalLayout_6 = new QVBoxLayout(selectSourceFrame);
        verticalLayout_6->setSpacing(0);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        createNewSource = new QPushButton(selectSourceFrame);
        createNewSource->setObjectName("createNewSource");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(createNewSource->sizePolicy().hasHeightForWidth());
        createNewSource->setSizePolicy(sizePolicy4);
        createNewSource->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));

        verticalLayout_6->addWidget(createNewSource);

        noExistingLabel = new QLabel(selectSourceFrame);
        noExistingLabel->setObjectName("noExistingLabel");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(noExistingLabel->sizePolicy().hasHeightForWidth());
        noExistingLabel->setSizePolicy(sizePolicy5);
        noExistingLabel->setAlignment(Qt::AlignCenter);

        verticalLayout_6->addWidget(noExistingLabel);

        existingScrollArea = new QScrollArea(selectSourceFrame);
        existingScrollArea->setObjectName("existingScrollArea");
        existingScrollArea->setFocusPolicy(Qt::NoFocus);
        existingScrollArea->setFrameShape(QFrame::NoFrame);
        existingScrollArea->setFrameShadow(QFrame::Plain);
        existingScrollArea->setLineWidth(0);
        existingScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
        existingScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        existingScrollArea->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        existingScrollArea->setWidgetResizable(true);
        existingScrollContents = new QWidget();
        existingScrollContents->setObjectName("existingScrollContents");
        existingScrollContents->setGeometry(QRect(0, 0, 819, 250));
        existingScrollContents->setAutoFillBackground(true);
        verticalLayout_4 = new QVBoxLayout(existingScrollContents);
        verticalLayout_4->setSpacing(0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        existingListFrame = new FlowFrame(existingScrollContents);
        existingListFrame->setObjectName("existingListFrame");
        existingListFrame->setFrameShape(QFrame::NoFrame);
        existingListFrame->setFrameShadow(QFrame::Plain);
        existingListFrame->setLineWidth(0);

        verticalLayout_4->addWidget(existingListFrame);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        existingScrollArea->setWidget(existingScrollContents);

        verticalLayout_6->addWidget(existingScrollArea);

        addExistingContainer = new QWidget(selectSourceFrame);
        addExistingContainer->setObjectName("addExistingContainer");
        addExistingContainer->setMinimumSize(QSize(0, 0));
        horizontalLayout_4 = new QHBoxLayout(addExistingContainer);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        addExistingButton = new QPushButton(addExistingContainer);
        addExistingButton->setObjectName("addExistingButton");
        addExistingButton->setEnabled(false);
        sizePolicy4.setHeightForWidth(addExistingButton->sizePolicy().hasHeightForWidth());
        addExistingButton->setSizePolicy(sizePolicy4);

        horizontalLayout_4->addWidget(addExistingButton);

        horizontalSpacer_4 = new QSpacerItem(40, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        horizontalSpacer_3 = new QSpacerItem(259, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout_6->addWidget(addExistingContainer);


        verticalLayout_2->addWidget(selectSourceFrame);


        verticalLayout_8->addWidget(selectSourceContainer);

        footer = new QFrame(sourcesFrame);
        footer->setObjectName("footer");
        footer->setFrameShape(QFrame::NoFrame);
        footer->setFrameShadow(QFrame::Plain);
        footer->setLineWidth(0);
        horizontalLayout_2 = new QHBoxLayout(footer);
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        sourceVisible = new QCheckBox(footer);
        sourceVisible->setObjectName("sourceVisible");
        sourceVisible->setChecked(true);

        horizontalLayout_2->addWidget(sourceVisible);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        buttonBox = new QDialogButtonBox(footer);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy6);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);
        buttonBox->setCenterButtons(false);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout_8->addWidget(footer);


        horizontalLayout->addWidget(sourcesFrame);

        horizontalLayout->setStretch(0, 1);
        horizontalLayout->setStretch(1, 4);

        verticalLayout_7->addWidget(dialogInner);

        QWidget::setTabOrder(sourceTypeList, sourceVisible);

        retranslateUi(OBSBasicSourceSelect);

        QMetaObject::connectSlotsByName(OBSBasicSourceSelect);
    } // setupUi

    void retranslateUi(QDialog *OBSBasicSourceSelect)
    {
        OBSBasicSourceSelect->setWindowTitle(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect", nullptr));
        OBSBasicSourceSelect->setProperty("class", QVariant(QString()));
        dialogInner->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "dialog-container", nullptr)));
#if QT_CONFIG(accessibility)
        selectTypeFrame->setAccessibleName(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.SelectType", nullptr));
#endif // QT_CONFIG(accessibility)
        selectTypeFrame->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "dialog-frame", nullptr)));
#if QT_CONFIG(accessibility)
        sourceTypeList->setAccessibleName(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.SelectType", nullptr));
#endif // QT_CONFIG(accessibility)
        sourceTypeList->setProperty("class", QVariant(QString()));
        sourcesFrame->setProperty("class", QVariant(QString()));
        selectSourceContainer->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "dialog-container", nullptr)));
        sourceSelectTitle->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.Recent", nullptr));
        sourceSelectTitle->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "text-title", nullptr)));
        sourceSelectDescription->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.Description", nullptr));
        sourceSelectDescription->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "text-small text-muted margin-y", nullptr)));
        deprecatedFrame->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "frame-notice", nullptr)));
        deprecatedCreateLabel->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.Deprecated.Create", nullptr));
#if QT_CONFIG(accessibility)
        selectSourceFrame->setAccessibleName(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.AddExisting", nullptr));
#endif // QT_CONFIG(accessibility)
        selectSourceFrame->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "dialog-container dialog-frame", nullptr)));
        createNewSource->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.NewSource", nullptr));
        createNewSource->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "btn-create-new", nullptr)));
        noExistingLabel->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.NoExisting", nullptr));
        noExistingLabel->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "text-muted", nullptr)));
        addExistingButton->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.NoSelection", nullptr));
        addExistingButton->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "button-primary", nullptr)));
        footer->setProperty("class", QVariant(QCoreApplication::translate("OBSBasicSourceSelect", "dialog-container", nullptr)));
        sourceVisible->setText(QCoreApplication::translate("OBSBasicSourceSelect", "Basic.SourceSelect.AddVisible", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OBSBasicSourceSelect: public Ui_OBSBasicSourceSelect {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OBSBASICSOURCESELECT_H
