/****************************************************************************
** Meta object code from reading C++ file 'AudioMixer.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../obs-studio/frontend/widgets/AudioMixer.hpp"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AudioMixer.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10AudioMixerE_t {};
} // unnamed namespace

template <> constexpr inline auto AudioMixer::qt_create_metaobjectdata<qt_meta_tag_ZN10AudioMixerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AudioMixer",
        "advAudioPropertiesClicked",
        "",
        "addSource",
        "uuid",
        "removeSource",
        "updatePreviewSources",
        "updateGlobalSources",
        "unhideAllAudioControls",
        "queueLayoutUpdate",
        "createVolumeControl",
        "VolumeControl*",
        "obs_source_t*",
        "source",
        "updateControlVisibility",
        "updateLayout",
        "toggleShowInactive",
        "checked",
        "toggleKeepInactiveLast",
        "toggleShowHidden",
        "toggleKeepHiddenLast",
        "mixerContextMenuRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'advAudioPropertiesClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addSource'
        QtMocHelpers::SlotData<void(QString)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'removeSource'
        QtMocHelpers::SlotData<void(QString)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updatePreviewSources'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateGlobalSources'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unhideAllAudioControls'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'queueLayoutUpdate'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createVolumeControl'
        QtMocHelpers::SlotData<VolumeControl *(obs_source_t *)>(10, 2, QMC::AccessPrivate, 0x80000000 | 11, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'updateControlVisibility'
        QtMocHelpers::SlotData<void(QString)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'updateLayout'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleShowInactive'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'toggleKeepInactiveLast'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'toggleShowHidden'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'toggleKeepHiddenLast'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'mixerContextMenuRequested'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AudioMixer, qt_meta_tag_ZN10AudioMixerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AudioMixer::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10AudioMixerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10AudioMixerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10AudioMixerE_t>.metaTypes,
    nullptr
} };

void AudioMixer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AudioMixer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->advAudioPropertiesClicked(); break;
        case 1: _t->addSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->removeSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->updatePreviewSources(); break;
        case 4: _t->updateGlobalSources(); break;
        case 5: _t->unhideAllAudioControls(); break;
        case 6: _t->queueLayoutUpdate(); break;
        case 7: { VolumeControl* _r = _t->createVolumeControl((*reinterpret_cast<std::add_pointer_t<obs_source_t*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<VolumeControl**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->updateControlVisibility((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->updateLayout(); break;
        case 10: _t->toggleShowInactive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->toggleKeepInactiveLast((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->toggleShowHidden((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->toggleKeepHiddenLast((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->mixerContextMenuRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AudioMixer::*)()>(_a, &AudioMixer::advAudioPropertiesClicked, 0))
            return;
    }
}

const QMetaObject *AudioMixer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioMixer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10AudioMixerE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int AudioMixer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void AudioMixer::advAudioPropertiesClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
